#### 使用订单号批量查询订单

##### 请求地址: https://m-api.lejian.com/open-api/V2/order/queryOrderByOrderNums?accessToken=ACCESS_TOKEN
##### 请求协议：HTTPS
##### 请求方式：POST
##### 需要签名：否
##### URL参数:

|参数名|是否必须|类型|说明|
|:----    |:---|:----- |-----   |
|accessToken |是  |string | 当前有效的accessToken |


##### POST参数示例
```json
{
	"orderNums":
		[
			"201200000000000",
			"201200000000001",
			"201200000000002"
		]
}
```
|参数名|是否必须|类型|说明|
|:---- |-----|:----- |-----|
|orderNums |是|array | 需要查询的订单号，最大不能超过10个 |

##### 返回示例:

```json
{
	"success":"T",
	"data":{
		"currentPage":1,
		"hasNextPage":false,
		"orders":
		[
			{
				"openId":"qzZytoGYOSYlNLC5aecUeyr67zJ2",
				"orderNum":"20170602182719769255420",
				"status":2,
				"exportStatus":0,
				"beginPeriod": "8:00",
				"endPeriod": "10:00",
				"brandId":3,
				"brandName":"爱康国宾",
				"hospitalName":"体检中心名称",
				"hospitalId":"1",
				"address":"广东省深圳市宝安区新湖路1333号",
				"canChangeDate": true,
				"canRevoke": true,
				"failMsg": "{\"errTypeCode\":\"2\",\"errTypeDesc\":\"分院排期已满，请切换分院、预约日期重试\",\"resultMsg\":\"\"预约失败：SCHE-004==扣排期失败:null\"\"}",
				"createTime":"2017-06-02 06:27:19",
				"examDate":"2017-06-20 12:00:00",
				"orderPrice":2000,
				"settlementDiscount":0.8,
				"items":
					[
						{
							"id":1223,
							"name":"内科检查1",
							"price":1000
						},
						{
							"id":122234,
							"name":"耳鼻喉科",
							"price":1000
						}
					],
				"useInfo": {
				   "gender": 0,
				   "idCard": "110101********3976",
				   "mobile": "199****7777",
				   "employeeId": "12345679",
				   "name": "张*"
				}
			}
		]
	},
	"msg":"success"
	
}
```

#### 返回参数说明:
*通俗易懂的参数不再说明*

|字段|类型|说明|
|:----    |-----|:----- |-----   |
|currentPage |integer | 当前页码 |
|hasNextPage |boolean | 本次查询是否还有下一页数据 |
|orders |Array | 订单列表 |
|address|String|体检中心详细地址|
|brandId|integer|机构品牌ID|
|brandName|String|机构品牌名称|
|canChangeDate|boolean|订单是否可以改期|
|canRevoke|boolean|订单是否可以取消|
|createTime|String|订单创建时间|
|beginPeriod|String|体检开始时间|
|endPeriod|String|体检结束时间|
|examDate|String|体检日期|
|hospitalId|integer|体检中心ID|
|hospitalName|String|体检中心名称|
|items|JSONObject|订单单项|
|checkItems|JSONObject| 单项体检情况 已检、拒检、未检，|
|status|int|订单状态，可能民营机构会存在中间态，如预约中，对接[消息推送](openapi-message)会获取终态|
|exportStatus|integer|订单导出状态（0：未导出 1：已导出）|
|refundAmount|integer|订单退款金额（当订单状态为examined时，会返回）|
|orderId|String|订单ID|
|orderNum|String|乐荐订单号|
|settlementDiscount|double| 结算折扣|
|orderPrice |integer|订单金额，单位分|
|useInfo.gender|integer| 用户性别|
|useInfo.idCard|String|用户身份证号（已脱敏）|
|useInfo.mobile|String|用户手机号（已脱敏）|
|useInfo.employeeId|String|员工号|
|useInfo.name|String|用户姓名（已脱敏）|
|openId|String|用户在开放平台的唯一标识（用户注册下单则返回该信息）|
|failMsg|String|失败原因（当订单为爱康美年等民营机构的异步订单时，返回最新一次操作的失败原因）失败原因不一定为json格式|
checkItems

|字段|类型|说明|
|:----|:----|
|checkState |int | 检查状态：1 已检，2，拒检，3 未检，4，延检  |
| localAdd  | boolean|是否现场加项：true现场加项  |
| name  | string|项目名称   |
|id|int|单项id
##### 注意：公立医院订单导出状态指的是该订单信息是否进入到体检中心系统，如果为已导出（错误码：201017），说明该订单已经进入体检中心系统，接口不能进行改期和撤销操作，如果确实需要进行以上操作，请人工联系每天健康客服


**status对照表[状态流转](open_order)**

|状态|说明|
|:----|:----|
| 0  | 待支付  |
| 2  | 已预约  |
| 20  | **预约失败**  |
| 21  | **预约中**  |
| 3  | 体检完成  |
| 41  | **改期中**  |
| 5  | 已撤销  |
| 51  |**撤销中**  |
| 6  | 删除  |
| 8  | 关闭  |
*
**注意：黑体加粗状态只会出现在爱康、美年、瑞慈、慈铭民营医院***
#### 备注:

- 更多返回错误代码请看[接口返回码说明](base_error_codes)